import { Component, OnInit, Inject, AfterContentInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material';
import { ConfirmDialogComponent } from 'app/commons/component/confirm-dialog/confirm-dialog.component';
import * as DetailStore from '../../store/detail';
import { DetailSelector } from '../../store';
import { Store, select } from '@ngrx/store';
import { Probe } from '../../model';
import { RPCError } from 'packages/core/rpc/error';

@Component({
  selector: 'of-probe-detail',
  templateUrl: './detail.component.html',
  styleUrls: ['./detail.component.scss']
})
export class DetailComponent implements OnInit, AfterContentInit {

  probe$ = this.store.pipe(select(DetailSelector.select('probe')));
  probe: Probe = null;

  probeAlias = '';
  probeId = undefined;
  isUpState = false;

  networkInfo = [
    {
      key: 'IP',
      value: '192.168.1.1'
    },
    {
      key: 'NIC',
      value: 'enps30'
    },
    {
      key: 'Targets',
      value: '12'
    },
  ];

  deviceInfo = [
    {
      key: 'OS',
      value: 'Linux'
    },
    {
      key: 'CPU',
      value: 'intel7...'
    },
    {
      key: 'Memory',
      value: '16GB'
    },
    {
      key: '...',
      value: '...'
    },
  ];

  probeInfo = [
    {
      key: 'Authorized at',
      value: String(new Date())
    },
    {
      key: 'Authorized by',
      value: 'insanity'
    },
    {
      key: 'Installed at',
      value: String(new Date())
    },
  ];

  constructor(
    private route: ActivatedRoute,
    private router: Router,
    public dialog: MatDialog,
    private store: Store<DetailStore.State>
  ) { }

  ngOnInit() {
    this.probeId = this.route.snapshot.paramMap.get('id');
    this.probeAlias = 'Probe Alias 블라블라';
  }

  ngAfterContentInit() {
    this.store.dispatch(
      new DetailStore.Read(
        { id: this.probeId }
      )
    );
    this.probe$.subscribe(
      (probe: Probe) => {
        console.log(probe);
        this.probe = probe;
      },
      (error: RPCError) => {
        console.log(error.message);
      }
    );
  }

  handleStartStop() {
    this.isUpState = !this.isUpState;
  }

  handleRemove() {
    const dialogRef = this.dialog.open(ConfirmDialogComponent, {
      width: '250px',
      data: {
        title: 'Remove',
        message: 'Are you sure?'
      }
    });

    dialogRef.afterClosed().subscribe(confirmed => {
      if (confirmed) {
        console.log('confirmed');
      }
      // 삭제 후 list로 back
    });
  }
}

